# Current features

- A Jupyter Book containing rudimentary documentation (which you are presumably reading right now)
- A makefile containing installation, formatting, and testing functionality, as well as specifications for a (currently unimplemented) changelog functionality
- A testing script, test_installation.py, for testing the proper installation of necessary libraries
- An integrated prototype of the reweight functionality, integrated_test.py, using simple PyTorch tensors to demonstrate intended functionality for survey data reweighting
